pub struct Interwiki {
pub prefix: String,
pub local_interwiki: bool,
}Expand description
Represents an interwiki object in the interwikimap field of a SiteInfo.
Contains only the fields required to generate two InterwikiSets that can be used
by a TitleCodec to parse the interwikis in a Title.
Supports formatversion=1 where the localinterwiki field is "" for local interwikis,
and formatversion=2 where it is true.
Fields
prefix: Stringlocal_interwiki: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Interwiki
impl<'de> Deserialize<'de> for Interwiki
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more